//
//  RNTrimmerView.h
//  VideoPlayer
//

#ifndef RNTrimmerView_h
#define RNTrimmerView_h

#import "ICGVideoTrimmer.h"
#import "React/RCTViewManager.h"
#import "React/RCTConvert.h"
#import "React/RCTBridge.h"

#endif /* RNTrimmerView_h */
